mathphys
========

Python library with math functions, physical constants and auxiliary functions

For installation instructions, read INSTALL.

INSTALL - mathphys
------------------

This package can be installed using setuptools (>=16.0) or via PyPi. Developed and tested with Python 3 (3.4).

To list commonly used commands, run
```command
make help
```

To install to a default Python directory, run

```command
make install
```

Use the appropriate command in `<python>`. Depending on permissions, it may be
necessary to run the command with sudo or as superuser.

To install a development version, with a link to the local package files in the
default Python directory, run
```command
make develop
```

Details and further options can be found in setuptools documentation.
